@@ -1,4 +1,4 @@
-__version__ = '0.12.4'
+__version__ = '0.14.3'
 
 from warnings import warn
 # load configuration file using utilix
@@ -13,17 +13,20 @@ except (FileNotFoundError, RuntimeError) as e:
     uconfig = None
 
 from .common import *
+# contexts.py below
+from .corrections_services import *
+from .get_corrections import *
+from .hitfinder_thresholds import *
 from .itp_map import *
-from .rundb import *
-from .online_monitor import *
 from .matplotlib_utils import *
 from .mini_analysis import *
 from .misc import *
+from .mongo_storage import *
+from .online_monitor import *
+from .rundb import *
 from .scada import *
+from .bokeh_utils import *
 
-from .get_corrections import *
-from .hitfinder_thresholds import *
-from .corrections_services import *
 
 from . import plugins
 from .plugins import *
