@@ -2,3 +2,5 @@ from . import quick_checks
 from . import records_matrix
 from . import waveform_plot
 from . import holoviews_waveform_display
+from . import bokeh_waveform_plot
+from . import event_display
