@@ -17,7 +17,6 @@ common_opts = dict(
         straxen.MergedS2s,
         straxen.Peaks,
         straxen.PeakBasics,
-        straxen.PeakPositions,
         straxen.PeakProximity],
     check_available=('raw_records', 'peak_basics'),
     store_run_fields=(
@@ -25,10 +24,13 @@ common_opts = dict(
         'start', 'end', 'livetime', 'mode'))
 
 xnt_common_config = dict(
-    n_nveto_pmts=120,
     n_tpc_pmts=straxen.n_tpc_pmts,
     n_top_pmts=straxen.n_top_pmts,
+    n_mveto_pmts=straxen.n_mveto_pmts,
+    n_nveto_pmts=straxen.n_nveto_pmts,
     gain_model=("CMT_model", ("to_pe_model", "ONLINE")),
+    gain_model_nv=("to_pe_constant", "adc_nv"),
+    gain_model_mv=("to_pe_constant", "adc_mv"),
     channel_map=immutabledict(
         # (Minimum channel, maximum channel)
         # Channels must be listed in a ascending order!
@@ -38,11 +40,10 @@ xnt_common_config = dict(
         aqmon_nv=(808, 815),  # nveto acquisition monitor
         tpc_blank=(999, 999),
         mv=(1000, 1083),
+        aux_mv=(1084, 1087),  # Aux mv channel 2 empty  1 pulser  and 1 GPS
         mv_blank=(1999, 1999),
         nveto=(2000, 2119),
         nveto_blank=(2999, 2999)),
-    nn_architecture=straxen.aux_repo + 'f0df03e1f45b5bdd9be364c5caefdaf3c74e044e/fax_files/mlp_model.json',
-    nn_weights=straxen.aux_repo + 'f0df03e1f45b5bdd9be364c5caefdaf3c74e044e/fax_files/mlp_model.h5', 
     # Clustering/classification parameters
     s1_max_rise_time=100,
 )
@@ -50,15 +51,27 @@ xnt_common_config = dict(
 # Plugins in these files have nT plugins, E.g. in pulse&peak(let)
 # processing there are plugins for High Energy plugins. Therefore do not
 # st.register_all in 1T contexts.
-have_nT_plugins = [straxen.nveto_recorder,
-                   straxen.nveto_pulse_processing,
-                   straxen.nveto_hitlets,
-                   straxen.acqmon_processing,
-                   straxen.pulse_processing,
-                   straxen.peaklet_processing,
-                   straxen.peak_processing,
-                   straxen.online_monitor,
-                   ]
+xnt_common_opts = common_opts.copy()
+xnt_common_opts['register'] = common_opts['register'] + [
+    straxen.PeakPositionsCNN,
+    straxen.PeakPositionsMLP,
+    straxen.PeakPositionsGCN,
+    straxen.PeakPositionsNT,
+    straxen.PeakBasicsHighEnergy,
+    straxen.PeaksHighEnergy,
+    straxen.PeakletsHighEnergy,
+    straxen.PeakletClassificationHighEnergy,
+    straxen.MergedS2sHighEnergy,
+]
+xnt_common_opts['register_all'] = common_opts['register_all'] + [
+    straxen.nveto_recorder,
+    straxen.veto_pulse_processing,
+    straxen.veto_hitlets,
+    straxen.acqmon_processing,
+    straxen.pulse_processing,
+    straxen.peaklet_processing,
+    straxen.online_monitor,
+]
 
 ##
 # XENONnT
@@ -72,13 +85,12 @@ def xenonnt_online(output_folder='./strax_data',
                    **kwargs):
     """XENONnT online processing and analysis"""
     context_options = {
-        **straxen.contexts.common_opts,
+        **straxen.contexts.xnt_common_opts,
         **kwargs}
 
     st = strax.Context(
         config=straxen.contexts.xnt_common_config,
         **context_options)
-    st.register_all(have_nT_plugins)
     st.register([straxen.DAQReader, straxen.LEDCalibration])
 
     st.storage = [straxen.RunDB(
@@ -134,16 +146,15 @@ def xenonnt_led(**kwargs):
 # This gain model is a temporary solution until we have a nice stable one
 def xenonnt_simulation(output_folder='./strax_data'):
     import wfsim
-    xnt_common_config['gain_model'] = ('to_pe_per_run',
-                                       straxen.aux_repo + '58e615f99a4a6b15e97b12951c510de91ce06045/fax_files/to_pe_nt.npy')
+    xnt_common_config['gain_model'] = ('to_pe_per_run', 'to_pe_nt.npy')
     st = strax.Context(
         storage=strax.DataDirectory(output_folder),
         config=dict(detector='XENONnT',
-                    fax_config=straxen.aux_repo + '17e83b1a8c02f56066081ebaefe5f625ebb2e287/fax_files/fax_config_nt.json',
+                    fax_config='fax_config_nt.json',
                     check_raw_record_overlaps=False,
                     **straxen.contexts.xnt_common_config,
                     ),
-        **straxen.contexts.common_opts)
+        **straxen.contexts.xnt_common_opts)
     st.register(wfsim.RawRecordsFromFaxNT)
     return st
 
@@ -175,7 +186,7 @@ def xenonnt_temporary_five_pmts(**kwargs):
 def xenonnt_initial_commissioning(*args, **kwargs):
     raise ValueError(
         'Use xenonnt_online. See' 
-        'https://xe1t-wiki.lngs.infn.it/doku.php?id=xenon:xenonnt:analysis:commissioning:straxen_contexts#update_09_nov_20')
+        'https://xe1t-wiki.lngs.infn.it/doku.php?id=xenon:xenonnt:analysis:commissioning:straxen_contexts#update_09_nov_20')  # noqa
 
 ##
 # XENON1T
@@ -191,6 +202,11 @@ x1t_context_config = {
         store_run_fields=tuple(
             [x for x in common_opts['store_run_fields'] if x != 'mode']
             + ['trigger.events_built', 'reader.ini.name']))}
+x1t_context_config.update(
+    dict(register=common_opts['register'] +
+                  [straxen.PeakPositions1T,
+                   straxen.RecordsFromPax,
+         ]))
 
 x1t_common_config = dict(
     check_raw_record_overlaps=False,
@@ -203,9 +219,9 @@ x1t_common_config = dict(
         diagnostic=(248, 253),
         aqmon=(254, 999)),
     hev_gain_model=('to_pe_per_run',
-                    'https://raw.githubusercontent.com/XENONnT/strax_auxiliary_files/master/to_pe.npy'),
+                    'to_pe.npy'),
     gain_model=('to_pe_per_run',
-                'https://raw.githubusercontent.com/XENONnT/strax_auxiliary_files/master/to_pe.npy'),
+                'to_pe.npy'),
     pmt_pulse_filter=(
         0.012, -0.119,
         2.435, -1.271, 0.357, -0.174, -0., -0.036,
@@ -237,7 +253,14 @@ def demo():
         forbid_creation_of=straxen.daqreader.DAQReader.provides,
         config=dict(**x1t_common_config),
         **x1t_context_config)
-    st.register(straxen.RecordsFromPax)
+
+    # Use configs that are always available
+    st.set_config(dict(
+        hev_gain_model=('to_pe_per_run', straxen.aux_repo +
+                        '3548132b55f81a43654dba5141366041e1daaf01/strax_files/to_pe.npy'),
+        gain_model=('to_pe_per_run', straxen.aux_repo +
+                    '3548132b55f81a43654dba5141366041e1daaf01/strax_files/to_pe.npy'),
+    ))
     return st
 
 
@@ -283,7 +306,6 @@ def xenon1t_dali(output_folder='./strax_data', build_lowlevel=False, **kwargs):
             straxen.daqreader.DAQReader.provides if build_lowlevel
             else straxen.daqreader.DAQReader.provides + ('records', 'peaklets')),
         **context_options)
-    st.register(straxen.RecordsFromPax)
     return st
 
 
@@ -305,7 +327,7 @@ def xenon1t_simulation(output_folder='./strax_data'):
     st = strax.Context(
         storage=strax.DataDirectory(output_folder),
         config=dict(
-            fax_config=straxen.aux_repo + '1c5793b7d6c1fdb7f99a67926ee3c16dd3aa944f/fax_files/fax_config_1t.json',
+            fax_config='fax_config_1t.json',
             detector='XENON1T',
             check_raw_record_overlaps=False,
             **straxen.contexts.x1t_common_config),
