@@ -8,7 +8,7 @@ __all__ += ['FIXED_TO_PE']
 
 
 @export
-def get_to_pe(run_id, gain_model, n_tpc_pmts):
+def get_to_pe(run_id, gain_model, n_pmts):
     if not isinstance(gain_model, tuple):
         raise ValueError(f"gain_model must be a tuple")
     if not len(gain_model) == 2:
@@ -31,9 +31,12 @@ def get_to_pe(run_id, gain_model, n_tpc_pmts):
             raise ValueError('CMT gain model should be similar to:'
                              '("CMT_model", ("to_pe_model", "v1"). Instead got:'
                              f'{model_conf}')
-        is_nt = n_tpc_pmts == straxen.n_tpc_pmts
+        # is this the best way to do this?
+        is_nt = n_pmts == straxen.n_tpc_pmts or n_pmts == straxen.n_nveto_pmts or n_pmts == straxen.n_mveto_pmts
+
         corrections = straxen.CorrectionsManagementServices(is_nt=is_nt)
-        to_pe = corrections.get_corrections_config(run_id, 'pmt_gains', model_conf)
+        to_pe = corrections.get_corrections_config(run_id, model_conf)
+
         return to_pe
 
     elif model_type == 'to_pe_per_run':
@@ -54,25 +57,31 @@ def get_to_pe(run_id, gain_model, n_tpc_pmts):
 
         try:
             # Uniform gain, specified as a to_pe factor
-            to_pe = np.ones(n_tpc_pmts, dtype=np.float32) * model_conf
+            to_pe = np.ones(n_pmts, dtype=np.float32) * model_conf
         except np.core._exceptions.UFuncTypeError as e:
             raise(str(e) +
                   f'\nTried multiplying by {model_conf}. Insert a number instead.')
     else:
         raise NotImplementedError(f"Gain model type {model_type} not implemented")
 
-    if len(to_pe) != n_tpc_pmts:
+    if len(to_pe) != n_pmts:
        raise ValueError(
             f"Gain model {gain_model} resulted in a to_pe "
-            f"of length {len(to_pe)}, but n_tpc_pmts is {n_tpc_pmts}!")
+            f"of length {len(to_pe)}, but n_pmts is {n_pmts}!")
     return to_pe
 
 
 FIXED_TO_PE = {
     # just some dummy placeholder for nT gains
-    'gain_placeholder': np.repeat(0.0085, straxen.n_tpc_pmts)
+    'gain_placeholder': np.repeat(0.0085, straxen.n_tpc_pmts),
+    # Gains which will preserve all areas in adc counts.
+    # Useful for debugging and tests.
+    'adc_tpc': np.ones(straxen.n_tpc_pmts),
+    'adc_mv': np.ones(straxen.n_mveto_pmts),
+    'adc_nv': np.ones(straxen.n_nveto_pmts)
 }
 
+
 @export
 def get_elife(run_id, elife_conf):
     if isinstance(elife_conf, tuple) and len(elife_conf) == 3:
@@ -80,8 +89,7 @@ def get_elife(run_id, elife_conf):
         is_nt = elife_conf[-1]
         cmt = straxen.CorrectionsManagementServices(is_nt=is_nt)
 
-        e = cmt.get_corrections_config(run_id, 'elife',
-                                       elife_conf[:2])
+        e = cmt.get_corrections_config(run_id, elife_conf[:2])
 
     elif isinstance(elife_conf, str):
         warn("get_elife will be replaced by CorrectionsManagementSevices",
