@@ -13,6 +13,9 @@ from .peaklet_processing import *
 from . import peak_processing
 from .peak_processing import *
 
+from .position_reconstruction import *
+from . import position_reconstruction
+
 from . import event_processing
 from .event_processing import *
 
@@ -27,11 +30,11 @@ from . import x1t_cuts
 from . import nveto_recorder
 from .nveto_recorder import *
 
-from . import nveto_pulse_processing
-from .nveto_pulse_processing import *
+from . import veto_pulse_processing
+from .veto_pulse_processing import *
 
-from . import nveto_hitlets
-from .nveto_hitlets import *
+from . import veto_hitlets
+from .veto_hitlets import *
 
 from . import acqmon_processing
 from .acqmon_processing import *
