@@ -5,6 +5,7 @@ import strax
 import straxen
 from .pulse_processing import HITFINDER_OPTIONS, HITFINDER_OPTIONS_he, HE_PREAMBLE
 from strax.processing.general import _touching_windows
+from warnings import warn
 
 export, __all__ = strax.exporter()
 
@@ -17,7 +18,7 @@ export, __all__ = strax.exporter()
                  help="Include this many ns left of hits in peaks"),
     strax.Option('peak_right_extension', default=200,
                  help="Include this many ns right of hits in peaks"),
-    strax.Option('peak_min_pmts', default=4,
+    strax.Option('peak_min_pmts', default=2,
                  help="Minimum number of contributing PMTs needed to define a peak"),
     strax.Option('peak_split_gof_threshold',
                  # See https://xe1t-wiki.lngs.infn.it/doku.php?id=
@@ -96,9 +97,15 @@ class Peaklets(strax.Plugin):
                     lone_hits=strax.hit_dtype)
 
     def setup(self):
+        if self.config['peak_min_pmts'] > 2:
+            # Can fix by resplitting, NotImplemented
+            raise warn(f"Raising the peak_min_pmts to "
+                       f"{self.config['peak_min_pmts']} interferes with "
+                       f"lone_hit definition. See "
+                       f"github.com/XENONnT/straxen/issues/295")
         self.to_pe = straxen.get_to_pe(self.run_id,
                                        self.config['gain_model'],
-                                       n_tpc_pmts=self.config['n_tpc_pmts'])
+                                       self.config['n_tpc_pmts'])
 
     def compute(self, records, start, end):
         r = records
@@ -387,9 +394,12 @@ def _peak_saturation_correction_inner(channel_saturated, records, p,
     strax.Option('le_to_he_amplification', default=20, track=True,
                  help="Difference in amplification between low energy and high "
                       "energy channels"),
-    strax.Option('peak_min_pmts_he', default=2, child_option=True, track=True,
+    strax.Option('peak_min_pmts_he', default=2,
+                 child_option=True, parent_option_name='peak_min_pmts',
+                 track=True,
                  help="Minimum number of contributing PMTs needed to define a peak"),
-    strax.Option('saturation_correction_on_he', default=False, child_option=True,
+    strax.Option('saturation_correction_on_he', default=False,
+                 child_option=True, parent_option_name='saturation_correction_on',
                  track=True,
                  help='On off switch for saturation correction for High Energy'
                       ' channels'),
@@ -401,7 +411,7 @@ class PeakletsHighEnergy(Peaklets):
     provides = 'peaklets_he'
     data_kind = 'peaklets_he'
     __version__ = '0.0.1'
-    child_ends_with = '_he'
+    child_plugin = True
 
     def infer_dtype(self):
         return strax.peak_dtype(n_channels=self.config['n_he_pmts'])
@@ -409,7 +419,7 @@ class PeakletsHighEnergy(Peaklets):
     def setup(self):
         self.to_pe = straxen.get_to_pe(self.run_id,
                                        self.config['gain_model'],
-                                       n_tpc_pmts=self.config['n_tpc_pmts'])
+                                       self.config['n_tpc_pmts'])
 
         buffer_pmts = np.zeros(self.config['he_channel_offset'])
         self.to_pe = np.concatenate((buffer_pmts, self.to_pe))
@@ -478,7 +488,7 @@ class PeakletClassificationHighEnergy(PeakletClassification):
     provides = 'peaklet_classification_he'
     depends_on = ('peaklets_he',)
     __version__ = '0.0.1'
-    child_ends_with = '_he'
+    child_plugin = True
 
     def compute(self, peaklets_he):
         return super().compute(peaklets_he)
@@ -596,7 +606,7 @@ class MergedS2sHighEnergy(MergedS2s):
     data_kind = 'merged_s2s_he'
     provides = 'merged_s2s_he'
     __version__ = '0.0.1'
-    child_ends_with = '_he'
+    child_plugin = True
 
     def infer_dtype(self):
         return strax.unpack_dtype(self.deps['peaklets_he'].dtype_for('peaklets_he'))
