@@ -15,6 +15,8 @@ def test_straxen():
 
             print("Downloading test data (if needed)")
             st = straxen.contexts.demo()
+            # Ignore strax-internal warnings
+            st.set_context_config({'free_options': tuple(st.config.keys())})
 
             run_df = st.select_runs(available='raw_records')
             print(run_df)
