@@ -13,6 +13,24 @@ N_CHUNKS = 2
 # Tools
 ##
 
+# Some configs are better obtained from the strax_auxiliary_files repo.
+# Let's use small files, we don't want to spend a lot of time downloading
+# some file.
+testing_config_nT = dict(
+    nn_architecture=
+    straxen.aux_repo + 'f0df03e1f45b5bdd9be364c5caefdaf3c74e044e/fax_files/mlp_model.json',
+    nn_weights=
+    straxen.aux_repo + 'f0df03e1f45b5bdd9be364c5caefdaf3c74e044e/fax_files/mlp_model.h5',
+    gain_model=
+    ('to_pe_per_run',
+     straxen.aux_repo + '58e615f99a4a6b15e97b12951c510de91ce06045/fax_files/to_pe_nt.npy')
+)
+
+testing_config_1T = dict(
+    hev_gain_model=('to_pe_constant', 0.0085),
+    gain_model=('to_pe_constant', 0.0085)
+)
+
 
 @strax.takes_config(
     strax.Option('secret_time_offset', default=0, track=False)
@@ -24,7 +42,10 @@ class DummyRawRecords(strax.Plugin):
     provides = ('raw_records',
                 'raw_records_he',
                 'raw_records_nv',
-                'raw_records_aqmon')
+                'raw_records_aqmon',
+                'raw_records_aux_mv',
+                'raw_records_mv'
+                )
     parallel = 'process'
     depends_on = tuple()
     data_kind = immutabledict(zip(provides, provides))
@@ -56,6 +77,7 @@ forbidden_plugins = tuple([p for p in
                            straxen.daqreader.DAQReader.provides
                            if p not in DummyRawRecords.provides])
 
+
 def _run_plugins(st,
                  make_all=False,
                  run_id=run_id,
@@ -102,10 +124,22 @@ def _run_plugins(st,
     print("Wonderful all plugins work (= at least they don't fail), bye bye")
 
 
-def _update_context(st, max_workers, fallback_gains=None):
+def _update_context(st, max_workers, fallback_gains=None, nt=True):
     # Change config to allow for testing both multiprocessing and lazy mode
     st.set_context_config({'forbid_creation_of': forbidden_plugins})
+    # Ignore strax-internal warnings
+    st.set_context_config({'free_options': tuple(st.config.keys())})
     st.register(DummyRawRecords)
+    if nt:
+        st.set_config(testing_config_nT)
+        if straxen.uconfig is None or True:
+            del st._plugin_class_registry['peak_positions_mlp']
+            del st._plugin_class_registry['peak_positions_cnn']
+            del st._plugin_class_registry['peak_positions_gcn']
+            st.register(straxen.PeakPositions1T)
+            print(f"Using {st._plugin_class_registry['peak_positions']} for posrec tests")
+    else:
+        st.set_config(testing_config_1T)
     try:
         if straxen.uconfig is None:
             raise ValueError('uconfig did not import')
@@ -133,6 +167,48 @@ def _update_context(st, max_workers, fallback_gains=None):
             'allow_lazy': False,
             'timeout': 60,  # we don't want to build travis for ever
         })
+    print('--- Plugins ---')
+    for k, v in st._plugin_class_registry.items():
+        print(k, v)
+
+
+def _test_child_options(st):
+    """
+    Test which checks if child options are handled correctly.
+    """
+    # Register all used plugins
+    plugins = []
+    already_seen = []
+    for data_type in st._plugin_class_registry.keys():
+        if data_type in already_seen or data_type in straxen.DAQReader.provides:
+            continue
+
+        p = st.get_single_plugin('0', data_type)
+        plugins.append(p)
+        already_seen += p.provides
+
+    # Loop over all plugins and check if child options were propagated to the parent:
+    for p in plugins:
+        for option_name, option in p.takes_config.items():
+            # Check if option is a child option:
+            if option.child_option:
+                # Get corresponding parent option. Do not have to test if
+                # parent option name is defined this is already done in strax
+                parent_name = option.parent_option_name
+
+                # Now check if parent config was replaced with child:
+                t = p.config[parent_name] == p.config[option_name]
+                assert t, (f'This is strange the child option "{option_name}" was set to '
+                           f'{p.config[option_name]}, but the corresponding parent config'
+                           f' "{parent_name}" has the value {p.config[parent_name]}. '
+                           f'Please check the options of {p.__class__.__name__} and if '
+                           'it is a child plugin (child_plugin=True)!')
+
+                # Test if parent names were removed from the lineage:
+                t = parent_name in p.lineage[p.provides[-1]][2]
+                assert not t, (f'Found "{parent_name}" in the lineage of {p.__class__.__name__}. '
+                               f'This should not have happend since "{parent_name}" is a child of '
+                               f'"{option_name}"!')
 
 ##
 # Tests
@@ -143,13 +219,14 @@ def test_1T(ncores=1):
     if ncores == 1:
         print('-- 1T lazy mode --')
     st = straxen.contexts.xenon1t_dali()
-    _update_context(st, ncores)
+    _update_context(st, ncores, nt=False)
 
     # Register the 1T plugins for this test as well
     st.register_all(straxen.plugins.x1t_cuts)
     _run_plugins(st, make_all=False, max_wokers=ncores)
     # Test issue #233
     st.search_field('cs1')
+    _test_child_options(st)
     print(st.context_config)
 
 
@@ -158,11 +235,13 @@ def test_nT(ncores=1):
         print('-- nT lazy mode --')
     st = straxen.contexts.xenonnt_online(_database_init=False)
     offline_gain_model = ('to_pe_constant', 'gain_placeholder')
-    _update_context(st, ncores, fallback_gains=offline_gain_model)
+    _update_context(st, ncores, fallback_gains=offline_gain_model, nt=True)
     # Lets take an abandoned run where we actually have gains for in the CMT
     _run_plugins(st, make_all=True, max_wokers=ncores, run_id='008900')
-     # Test issue #233
+    # Test issue #233
     st.search_field('cs1')
+    # Test of child plugins:
+    _test_child_options(st)
     print(st.context_config)
 
 
